================================================================================
moban-haml
================================================================================

.. image:: https://api.travis-ci.org/moremoban/moban-haml.svg
   :target: http://travis-ci.org/moremoban/moban-haml

.. image:: https://codecov.io/github/moremoban/moban-haml/coverage.png
   :target: https://codecov.io/github/moremoban/moban-haml


.. image:: https://readthedocs.org/projects/moban-haml/badge/?version=latest
   :target: http://moban-haml.readthedocs.org/en/latest/


Installation
================================================================================

You can get it:

.. code-block:: bash

    $ git clone https://github.com/moremoban/moban-haml.git
    $ cd moban-haml
    $ python setup.py install
